"""
    Module for handling syncing two animations one to one.
    The goal here is to zip up two classes and their respective animations,
    and create a joint class with the same animations that runs the animations
    for both classes at the same time. This way we can connect two isomorphic
    views of the same concept and visualize them at the same time. 
"""


class OneToOneSync:
    pass
