"""
    Animated flow charts. 
"""
from manim import *


class FlowGraph(VGroup):
    """Graph container"""

    pass


class FlowNode(VGroup):
    """Node in the FlowGraph"""

    pass


class DataNode(FlowNode):
    """Node that outputs data"""

    pass
