from setuptools import setup, find_packages

setup(
    name="manim_ml",
    version="0.0.13",
    description=(" Machine Learning Animations in python using Manim."),
    packages=find_packages(),
)
